==> sdlskk-0.1.tar.gz: sdlskk-0.1/list.c <==
#include "sdlskk_internal.h"
#include <stdlib.h>

SDLSKK_StrList* SDLSKK_StrList_new( void )
{
  SDLSKK_StrList* list = malloc( sizeof(SDLSKK_StrList) );
  SDLSKK_ListElement *begin, *end;
  begin = malloc( sizeof(SDLSKK_ListElement) );
  end = malloc( sizeof(SDLSKK_ListElement) );
  list->begin = begin;
  list->end = end;
  begin->next = end;
  begin->prev = NULL;
  end->prev = begin;
  end->next = NULL;
  begin->val = end->val = NULL;
  return list;
}

SDLSKK_ListElement* SDLSKK_StrList_find( SDLSKK_StrList* list, SDLSKK_Char* val )
{
  SDLSKK_ListElement* element;
  for( element = list->begin->next;
       element != list->end;
       element = element->next ){
    if( SDLSKK_str_equal( element->val, val ) ){
      return element;
    }
  }
  return NULL;
}

/*  prev -> locate -> next   ==>    prev -> new_element -> locate -> next */
void SDLSKK_StrList_insert( SDLSKK_StrList* list, SDLSKK_ListElement *locate,
			    SDLSKK_Char* val )
{
  SDLSKK_ListElement* new_element = malloc( sizeof(SDLSKK_ListElement) );
  new_element->val = val;
  new_element->prev = locate->prev;
  new_element->next = locate;
  locate->prev->next = new_element;
  locate->prev = new_element;
}

void SDLSKK_StrList_push( SDLSKK_StrList* list, SDLSKK_Char* val )
{
  SDLSKK_StrList_insert( list, list->end, val );
}

void SDLSKK_StrList_shift( SDLSKK_StrList* list, SDLSKK_Char* val )
{
  SDLSKK_StrList_insert( list, list->begin->next, val );
}

void SDLSKK_StrList_delete( SDLSKK_StrList* list )
{
  SDLSKK_ListElement* element;
  SDLSKK_ListElement* next_element;
  
  for( element = list->begin; element != NULL; ){
    next_element = element->next;
    free( element );
    element = next_element;
  }
  free( list );
  return;
}

void SDLSKK_StrList_delete_all( SDLSKK_StrList* list )
{
  SDLSKK_ListElement* element;
  SDLSKK_ListElement* next_element;
  
  for( element = list->begin; element != NULL; ){
    next_element = element->next;
    free( element->val );	  
    free( element );
    element = next_element;
  }
  free( list );
  return;
}

==> sdlskk-0.2.tar.gz: sdlskk-0.2/list.c <==
#include "sdlskk_internal.h"
#include <stdlib.h>

SDLSKK_StrList* SDLSKK_StrList_new( void )
{
  SDLSKK_StrList* list = SDLSKK_malloc( sizeof(SDLSKK_StrList) );
  SDLSKK_ListElement *begin, *end;
  begin = SDLSKK_malloc( sizeof(SDLSKK_ListElement) );
  end = SDLSKK_malloc( sizeof(SDLSKK_ListElement) );
  list->begin = begin;
  list->end = end;
  begin->next = end;
  begin->prev = NULL;
  end->prev = begin;
  end->next = NULL;
  begin->val = end->val = NULL;
  return list;
}

SDLSKK_ListElement* SDLSKK_StrList_find( SDLSKK_StrList* list, SDLSKK_Char* val )
{
  SDLSKK_ListElement* element;
  for( element = list->begin->next;
       element != list->end;
       element = element->next ){
    if( SDLSKK_str_equal( element->val, val ) ){
      return element;
    }
  }
  return NULL;
}

/*  prev -> locate -> next   ==>    prev -> new_element -> locate -> next */
void SDLSKK_StrList_insert( SDLSKK_StrList* list, SDLSKK_ListElement *locate,
			    SDLSKK_Char* val, int save )
{
  SDLSKK_ListElement* new_element = SDLSKK_malloc( sizeof(SDLSKK_ListElement) );
  new_element->val = val;
  new_element->prev = locate->prev;
  new_element->next = locate;
  new_element->save = save;
  locate->prev->next = new_element;
  locate->prev = new_element;
}

void SDLSKK_StrList_push( SDLSKK_StrList* list, SDLSKK_Char* val, int save )
{
  SDLSKK_StrList_insert( list, list->end, val, save );
}

void SDLSKK_StrList_shift( SDLSKK_StrList* list, SDLSKK_Char* val, int save )
{
  SDLSKK_StrList_insert( list, list->begin->next, val, save );
}

void SDLSKK_StrList_delete( SDLSKK_StrList* list )
{
  SDLSKK_ListElement* element;
  SDLSKK_ListElement* next_element;
  
  for( element = list->begin; element != NULL; ){
    next_element = element->next;
    free( element );
    element = next_element;
  }
  free( list );
  return;
}

void SDLSKK_StrList_delete_all( SDLSKK_StrList* list )
{
  SDLSKK_ListElement* element;
  SDLSKK_ListElement* next_element;
  
  for( element = list->begin; element != NULL; ){
    next_element = element->next;
    free( element->val );	  
    free( element );
    element = next_element;
  }
  free( list );
  return;
}
